@@ -326,6 +326,8 @@ class TestUnit(unittest.TestCase):
         self.assertFalse(isna_element(datetime.date(2020, 12, 31)))
         self.assertFalse(isna_element(False))
 
+    #---------------------------------------------------------------------------
+
     def test_dtype_from_element_core_dtypes(self) -> None:
         dtypes = [
                 np.longlong,
@@ -367,11 +369,11 @@ class TestUnit(unittest.TestCase):
         NT = collections.namedtuple('NT', tuple('abc'))
 
         dtype_obj_pairs = [
-                (np.int_, 12),
-                (np.float_, 12.0),
+                (np.int64, 12),
+                (np.float64, 12.0),
                 (np.bool_, True),
                 (np.dtype('O'), None),
-                (np.float_, float('NaN')),
+                (np.float64, float('NaN')),
                 (np.dtype('O'), object()),
                 (np.dtype('O'), (1, 2, 3)),
                 (np.dtype('O'), NT(1, 2, 3)),
@@ -393,6 +395,12 @@ class TestUnit(unittest.TestCase):
             self.assertEqual(np.dtype(f'|S{size}'), dtype_from_element(bytes(size)))
             self.assertEqual(np.dtype(f'<U{size}'), dtype_from_element('x' * size))
 
+    def test_dtype_from_element_int(self) -> None:
+        # make sure all platforms give 64 bit int
+        self.assertEqual(str(dtype_from_element(3)), 'int64')
+
+    #---------------------------------------------------------------------------
+
     def test_get_new_indexers_and_screen_a(self) -> None:
         indexersA = np.array([9, 9, 9, 9, 0, 0, 1, 4, 5, 0, 0, 0, 1], dtype=np.int64)
         postA = get_new_indexers_and_screen_full(indexersA, np.arange(10, dtype=np.int64))
